function loader() {
  return "a { color: red };";
}

module.exports = loader;
